
{ Paintplu.pas demonstrates how to use TDEventRecorder class in Delphi
  Copyright  1998. Galina Tydykov (Boston, USA, CompuServe 104052,2577).
  Published by permission of SonaMed Corp}

unit Paintplu;

interface

uses
  SysUtils, Windows, Messages, Classes, Graphics, Controls,Forms, Dialogs,
  StdCtrls, ExtCtrls, EvRecorder;

type
  TFrmPaintAndPlay = class(TForm)
    Panel1: TPanel;
    Panel2: TPanel;
    Panel3: TPanel;
    PanelPaint: TPanel;
    BtnPlayEvents: TButton;
    BtnClearEvents: TButton;
    BtnGreen: TButton;
    BtnYellow: TButton;
    BtnRed: TButton;
    TimerPlayBack: TTimer;
    ListBoxShowEvents: TListBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure BtnGreenClick(Sender: TObject);
    procedure BtnPlayEventsClick(Sender: TObject);
    procedure TimerPlayBackTimer(Sender: TObject);
    procedure BtnYellowClick(Sender: TObject);
    procedure BtnClearEventsClick(Sender: TObject);
    procedure ListBoxShowEventsDrawItem(Control: TWinControl; Index: Integer;
      Rect: TRect; State: TOwnerDrawState);
    procedure BtnRedClick(Sender: TObject);
    procedure ListBoxShowEventsKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ListBoxShowEventsClick(Sender: TObject);
  private
    { Private declarations }
   EventRecorder: TDEventRecorder;{ EventsRecorder}
   CurrentIndex: longint;{current index of EventList}
   BrushGreen:TBrush;  {brushes to draw the colored rectangles for the items }
   BrushRed:TBrush;
   BrushYellow:TBrush;
   procedure StoreEvent(Sender: TObject);
  public
    { Public declarations }
  end;

var
  FrmPaintAndPlay: TFrmPaintAndPlay;

implementation

{$R *.DFM}

procedure TFrmPaintAndPlay.FormCreate(Sender: TObject);
begin
  {Create objects}
   EventRecorder:= TDEventRecorder.create;
   BrushGreen:=TBrush.create;
   BrushRed:=TBrush.create;
   BrushYellow:=TBrush.create;

   BrushGreen.color:=ClLime;
   BrushRed.color:=ClRed;
   BrushYellow.color:=ClYellow;
end;

procedure TFrmPaintAndPlay.FormDestroy(Sender: TObject);
begin
  {Free objects}
   EventRecorder.free;
   BrushGreen.free;
   BrushYellow.free;
   BrushRed.free;
end;

procedure TFrmPaintAndPlay.StoreEvent(Sender: TObject);
begin
  {Store Event  EventsRecorder}
  if Sender is TButton then
  begin
    TClickItem.create(EventRecorder);
    TClickItem(EventRecorder.EventItem[EventRecorder.count-1]).OnClick:=(Sender as TButton).OnClick;
  end;
end;

procedure TFrmPaintAndPlay.BtnGreenClick(Sender: TObject);
begin
  with PanelPaint do { Paint the PanelPaint }
  begin
    color:=ClLime;
    repaint;
  end;
  if sender=BtnGreen then
  begin
    {This call is made by clicking button - not from from Events List}
    StoreEvent(BtnGreen); {add event to the EventsRecorder }
    ListBoxShowEvents.items.addObject('',BrushGreen);{add Brush to the ListBoxShowEvents}
    ListBoxShowEvents.update;
  end;
end;

procedure TFrmPaintAndPlay.BtnYellowClick(Sender: TObject);
begin
  with PanelPaint do
  begin
   color:=ClYellow;
   repaint;
  end;
  if sender=BtnYellow then
  begin
    ListBoxShowEvents.items.addObject('',BrushYellow);
    ListBoxShowEvents.update;
    StoreEvent(BtnYellow);
  end;
end;

procedure TFrmPaintAndPlay.BtnRedClick(Sender: TObject);
begin
  with PanelPaint do
  begin
    color:=clRed;
    repaint;
  end;
  if sender=BtnRed then
  begin
    ListBoxShowEvents.items.addObject('',BrushRed);
    ListBoxShowEvents.update;
    StoreEvent(BtnRed);
  end;
end;

procedure TFrmPaintAndPlay.BtnPlayEventsClick(Sender: TObject);
begin
  CurrentIndex:=0;
  ListBoxShowEvents.repaint;
  TimerPlayBack.enabled:=true; {Playing of stored events}
end;

procedure TFrmPaintAndPlay.TimerPlayBackTimer(Sender: TObject);
begin
  {Playing of stored events}
  TimerPlayBack.enabled:=false   ;
  if CurrentIndex<=EventRecorder.count-1 then
  begin
    ListBoxShowEvents.repaint;
    {Play current Event}
    TClickItem(EventRecorder.EventItem[CurrentIndex]).OnClick(sender);
    CurrentIndex:=CurrentIndex+1;
    {Move to next Item}
    TimerPlayBack.enabled:=true;
  end;
end;


procedure TFrmPaintAndPlay.BtnClearEventsClick(Sender: TObject);
begin
   EventRecorder.clear;
   ListBoxShowEvents.clear;
end;

procedure TFrmPaintAndPlay.ListBoxShowEventsDrawItem(Control: TWinControl; Index: Integer;
  Rect: TRect; State: TOwnerDrawState);
var
  CurBrush: TBrush;
begin
  with (Control as TListBox).Canvas do
  begin
    CurBrush:=TBrush((Control as TListBox).Items.Objects[Index]);
    if CurBrush <> nil then
    begin
      {draw colored rectangle}
      Brush.Color:= CurBrush.Color;
      FillRect(Rect);
      if Index=CurrentIndex then
      begin
        {Add sliding effect:                                                    }
        {      draws black frame on rectangle corresponding to the CurrentIndex }
        Brush.Color:= clBlack;
        FrameRect(Rect);
      end
    end;
  end;
end;

procedure TFrmPaintAndPlay.ListBoxShowEventsKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  {We can delete any event from EventsRecorder  - on Delete key}
  if Key=VK_DELETE then
  begin
    EventRecorder.delete(CurrentIndex);
    ListBoxShowEvents.items.delete(CurrentIndex);
    if CurrentIndex>EventRecorder.count-1 then
     CurrentIndex:=CurrentIndex-1;
  end
end;

procedure TFrmPaintAndPlay.ListBoxShowEventsClick(Sender: TObject);
begin
  CurrentIndex:=ListBoxShowEvents.ItemIndex;
  ListBoxShowEvents.repaint;
  TClickItem(EventRecorder.EventItem[CurrentIndex]).OnClick(sender);
end;

{ This software is provided "AS IS," without a warranty of any kind.
 *ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES,
 *INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 *PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY EXCLUDED.
 *SONAMED SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE
 *AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THE SOFTWARE OR
 *ITS DERIVATIVES. IN NO EVENT WILL SONAMED BE LIABLE FOR ANY LOST
 *REVENUE, PROFIT OR DATA, OR FOR DIRECT,INDIRECT, SPECIAL, CONSEQUENTIAL,
 *INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE
 *THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE
 *SOFTWARE, EVEN IF SONAMED HAS BEEN ADVISED OF THE POSSIBILITY OF
 *SUCH DAMAGES
}

end.

